##checks that cross-validation using evaluate produces the same values
##of UnoC and HarrellC as when doing the cross-validation manually.

testEvaluationsurv <- function(){
    require(survHD)
    require(survival)

    set.seed(1)
    nsamples <- 100
    X <- matrix(rnorm(nsamples*500),nrow=nsamples)
    colnames(X) <- make.names(1:ncol(X))
    rownames(X) <- make.names(1:nrow(X))
    ##Illegal characters in column and row names should not break things:
    bad.characters <- c("3", "`", "@", "/", "-", " ", "	", "\n", "\\")
    colnames(X) <- paste(sample(bad.characters, ncol(X), replace=TRUE), colnames(X), sep="")
    rownames(X) <- paste(sample(bad.characters, nrow(X), replace=TRUE), rownames(X), sep="")
    time <- rexp(nsamples)
    cens <- sample(0:1,size=nsamples,replace=TRUE)
    y <- Surv(time,cens)

    bootds <- generateLearningsets(y = y, method = "CV", fold = 8, niter = 2, strat = FALSE)

    ridgeclass <- learnSurvival(X=X, y=y, LearningSets = bootds, survmethod="coxBoostSurv", stepno=100)
    ## manual calculation of harrellC:
    test.boot <- t(sapply(1:nrow(bootds@learnmatrix), function(i){
        learnind <- bootds@learnmatrix[i,]
        manual.preds <- predict(ridgeclass@ModelLearnedlist[[i]], newdata=ridgeclass@X,type='lp')@lp
        output <- c(evaluate(new('LinearPrediction',lp=manual.preds[-ridgeclass@ModelLearnedlist[[i]]@learnind]),newy=ridgeclass@y[-ridgeclass@ModelLearnedlist[[i]]@learnind,],measure=new('HarrellC')),
                    evaluate(ridgeclass,measure="HarrellC")@result[[i]])
        names(output) <- c("manual","evaluationSurv")
        return(output)
    }
                          )
                   )
    checkEquals(test.boot[,1],test.boot[,2])

    ## manual calculation of unoC:
    test.boot <- t(sapply(1:nrow(bootds@learnmatrix), function(i){
        learnind <- bootds@learnmatrix[i,]
        manual.preds <- predict(ridgeclass@ModelLearnedlist[[i]], newdata=ridgeclass@X,type='lp')@lp
        output <- c(evaluate(new('LinearPrediction',lp=manual.preds[-ridgeclass@ModelLearnedlist[[i]]@learnind]),newy=ridgeclass@y[-ridgeclass@ModelLearnedlist[[i]]@learnind,],measure=new('UnoC'), add=list(tau=10)),
                    evaluate(ridgeclass,measure="UnoC",tau=10)@result[[i]])
        names(output) <- c("manual","evaluationSurv")
        return(output)
    }
                          )
                   )
    checkEquals(test.boot[,1],test.boot[,2])
    
     # test slightly modified survC1 example
     ##########################################################################
     D=CompCase(pbc[1:200,c(2:4,14)]) 
     D[,2]=as.numeric(D[,2]==2)
     
     tau=365.25*8
     fit <- coxph(formula = Surv(time, status) ~ copper,D)
     C=Inf.Cval(cbind(D[,1:2],predict(fit)), tau, itr=10,seed=2)  
     eval.output <- evaluate(fit, newdata=D, newy=Surv(D$time, D$status),
     measure="UnoC", tau=365.25*8)
     checkEqualsNumeric(C$Dhat, eval.output@result[[1]])

     # PErrC not working
     ##########################################################################
    set.seed(2)
    nsamples <- 100
    X <- matrix(rnorm(nsamples*200),nrow=nsamples)
    colnames(X) <- make.names(1:ncol(X))
    rownames(X) <- make.names(1:nrow(X))
    time <- rexp(nsamples)
    cens <- sample(0:1,size=nsamples,replace=TRUE)
    y <- Surv(time,cens)
    lrs <- rnorm(25)
    names(lrs) <- rownames(X)[1:25]
    #lrs.obj <- new("ModelLinear", coefficients=lrs, modeltype="compoundcovariate",linear.predictor=new('LinearPrediction'))
	#lrs.obj <- new("ModelLinear", coefficients=lrs, modeltype="compoundcovariate",linear.predictor=predict(lrs.obj,newdata=X,type='lp'))
    #evaluate(lrs.obj,newdata=X,newy=y,measure="PErrC", timegrid=0:3)

}
