##test independent evaluation when newdata has extra features or
##missing features

testIndependenteval <- function(){
    require(survHD)
    require(survival)

    set.seed(1)
    nsamples <- 100
    X <- matrix(rnorm(nsamples*500),nrow=nsamples)
    colnames(X) <- make.names(1:ncol(X))
    rownames(X) <- make.names(1:nrow(X))
    time <- rexp(nsamples)
    cens <- sample(0:1,size=nsamples,replace=TRUE)
    y1 <- Surv(time,cens)

    X2 <- matrix(rnorm(nsamples*500),nrow=nsamples)
    dimnames(X2) <- dimnames(X)
    time <- rexp(nsamples)
    cens <- sample(0:1,size=nsamples,replace=TRUE)
    y2 <- Surv(time,cens)

    pen.object <- learnSurvival(X=X, y=y1, survmethod="coxBoostSurv", stepno=100)


    test.HC <- evaluate(pen.object, measure="HarrellC", newdata=X2, newy=y2)@result[[1]]
    test.UC <- evaluate(pen.object, measure="UnoC", newdata=X2, newy=y2, tau=5)@result[[1]]
    test.PC <- evaluate(pen.object, measure="PErrC", newdata=X2, newy=y2, timegrid=2:3)@result[[1]]


    ##when newdata has some extra features and different column orders
    extra <- matrix(rnorm(nsamples*10),nrow=nsamples)
    colnames(extra) <- paste("E",1:ncol(extra),sep="")
    X3 <- cbind(X2, extra)
    X3 <- X3[, sample(1:ncol(X3))]

    test.HC3 <- evaluate(pen.object, measure="HarrellC", newdata=X3, newy=y2)@result[[1]]
##    test.UC3 <- evaluate(pen.object, measure="UnoC", newdata=X3, newy=y2, tau=max(y[,2]))@result[[1]]
    test.UC3 <- evaluate(pen.object, measure="UnoC", newdata=X3, newy=y2, tau=5)@result[[1]]
    test.PC3 <- evaluate(pen.object, measure="PErrC", newdata=X3, newy=y2, timegrid=2:3)@result[[1]]

    checkEquals(test.HC, test.HC3)
    checkEquals(test.UC, test.UC3)
    checkEquals(test.PC, test.PC3)

    ##when newdata is missing some features:
    X4 <- X2[,-1:-10]
    test.HC4 <- evaluate(pen.object, measure="HarrellC", newdata=X4, newy=y2, imputezero=TRUE)@result[[1]]
    test.UC4 <- evaluate(pen.object, measure="UnoC", newdata=X4, newy=y2, tau=5, imputezero=TRUE)@result[[1]]
    test.PC4 <- evaluate(pen.object, measure="PErrC", newdata=X4, newy=y2, timegrid=2:3, imputezero=TRUE)@result[[1]]

    ##These should be the same because coefficients 1:10 are zero in this example
    checkEquals(test.HC, test.HC4)
    checkEquals(test.UC, test.UC4)
    checkEquals(test.PC, test.PC4)
}
