##this unit test makes sure that "fast" and "slow" versions of
##rowCoxTests function produce the same output, including when
##changing the order of variables
testRowCoxTests <- function(){
    require(survival)
    require(survHD)
    ##simulate X and y
    rows <- 500
    cols <- 100
    set.seed(1234)
    X <- matrix( rnorm( rows * cols ), nrow=rows, ncol=cols)
    rownames(X) <- paste("v",1:nrow(X),sep="")
    colnames(X) <- paste("s",1:ncol(X),sep="")
    time <- rnorm( n=ncol(X)-25, mean=100 )
    time <- c(time,time[1:25])  ## introduce ties
    ##censoring(1->death)
    status <- rbinom( n=ncol(X), size=1, prob=0.8 )
    ##survival object
    y <- Surv( time, status )

    ##using fast method (C loop) and gold standard slow (R loop on coxph):
    output.fast <- rowCoxTests(X, y, option="fast")
    output.slow <- rowCoxTests(X, y, option="slow")

    ##Do it again without the first variable
    X2 <- X[-1,]  
    output2.fast <- rowCoxTests(X2, y, option="fast")
    output2.slow <- rowCoxTests(X2, y, option="slow")

    checkEquals( output.fast[,1], output.slow[,1] )
    checkEquals( output.fast[,2], output.slow[,2] )
    checkEquals( output.fast[,3], output.slow[,3] )

    checkEquals( output.fast[-1,1], output2.fast[,1] )
    checkEquals( output.fast[-1,2], output2.fast[,2] )
    checkEquals( output.fast[-1,3], output2.fast[,3] )
    checkEquals( output.slow[-1,1], output2.slow[,1] )
    checkEquals( output.slow[-1,2], output2.slow[,2] )
    checkEquals( output.slow[-1,3], output2.slow[,3] )

}
