\name{compare}
\alias{compare}
\alias{compare,LearnOut,LearnOut-method}
\alias{compare,ModelLearned,ModelLearned-method}
\alias{compare,ModelBase,ModelBase-method}
\alias{compare,LinearPrediction,LinearPrediction-method}
\alias{compare,IDI,missing-method}
\alias{compare,NRI,missing-method}
\alias{compare,MIRS,missing-method}
\alias{compare,CDelta,missing-method}

\title{Comparison of two survival methods}
\description{This function compares the performance of two models on new survival data
with regard to different measures.
}
\usage{
\S4method{compare}{LearnOut,LearnOut}(obj1,obj2,measure, newdata = NULL, newy = NULL, ...)
\S4method{compare}{ModelLearned,ModelLearned}(obj1,obj2, measure, newdata, newy, ...)
\S4method{compare}{ModelBase,ModelBase}(obj1,obj2, measure, newdata, newy, ...)
}
\arguments{
  \item{obj1}{An object of class \code{ModelLearned}, \code{LearnOut} or \code{ModelBase} representing the first method to be compared}
   \item{obj2}{An object of class \code{ModelLearned}, \code{LearnOut} or \code{ModelBase} representing the second method to be compared}
   				\item{measure}{The measure (as character) to be used for comparing the two models:
   				\describe{
   				\item{\code{"IDI"}}{ Integrated Discrimination Improvement Index (see package \code{survIDINRI})}
   				\item{\code{"NRI"}}{ Category-less Net Reclassification Index (see package \code{survIDINRI})}
   				\item{\code{"MIRS"}}{ Median Improvement in Risk Score (see package \code{survIDINRI})}
   				\item{\code{"CDelta"}}{ Difference in C-Statstic (see package \code{survC1}) }
   				}}
                 \item{newdata}{if the model is to be compared on independent new data these can be specified here. If obj1 and obj2 are of class \code{ModelLearned} this argument is obligatory.}
                 \item{newy}{survival response for the independent test data mentioned in the previous \code{newdata} argument. It is also obligatory if obj1 and obj2 are of class \code{ModelLearned}.}
                 \item{\dots}{ further arguments to be passed to .}
                            }
      
\value{A list containing the measure IDI and NRI among many other  (see package survIDINRI for more detailed information)}
\references{ 

Hajime Uno and Tianxi Cai (2012). survIDINRI: IDI and NRI for comapring competing risk prediction models with censored survival data.

}
            

\author{Christoph Bernau \email{bernau@ibe.med.uni-muenchen.de}}

\seealso{\code{\link{learnSurvival}}}
\examples{
data(beer.exprs)
data(beer.survival)
X<-t(as.matrix(beer.exprs))
y<-Surv(beer.survival$os,beer.survival$status)
ls<-generateLearningsets(y=y,method='CV',fold=3)
gsel<-geneSelection(X=X,y=y,LearningSets=ls, method='fastCox')
coxboostmodel1<-learnSurvival(y=y,X=X,survmethod='coxBoostSurv',stepno=20,LearningSets=ls,GeneSel=gsel,nbgene=500)
coxboostmodel2<-learnSurvival(y=y,X=X,survmethod='coxBoostSurv',stepno=200,LearningSets=ls,GeneSel=gsel,nbgene=500)
options(error=recover)
comp<-compare(coxboostmodel1,coxboostmodel2,measure='IDI',t0=50)
###first fold
estimate(comp[[1]])
	
}

\keyword{multivariate}

