\name{computeZ}
\alias{computeZ}
\alias{computeZ-methods}
\alias{computeZ,list,list-method}
\title{General method for computing the Zmatrix (leave-one-in
  cross-study validation).}
\description{
Computes a complete Zmatrix for a list of input \code{X}-arguments as in 
\code{\link{learnSurvival}} and a corresponding list of
\code{y}-arguments as in \code{\link{learnSurvival}}. Each data set is
used one for training and subsequently evaluated on all other data sets
passed via \code{Xlist} and \code{ylist}. However, no
within-study-validation is performed.
}
\usage{
\S4method{computeZ}{list,list}(Xlist, ylist, survmethod, measure,packagetune=FALSE,add.surv = list(), add.tune = list(),add.measure=list(), plot=FALSE,trace = TRUE,names=NULL,seed=238,...) 
}
\arguments{
 \item{Xlist}{List of gene expression data. The following formats are
   available for the entries of this list (see also \code{\link{learnSurvival}}):
  \itemize{
   \item{\code{matrix}} Rows correspond to observations, columns to variables.
   \item{\code{data.frame}}  Rows correspond to observations, columns to variables.
   \item{\code{ExpressionSet}} survHD will extract the expressions using exprs().
  } }
  \item{ylist}{List of survival responses, each entry of the list can be the
    following (see also \code{\link{learnSurvival}}):
  \itemize{
   \item{\code{Surv}} if \code{X} is of type data.frame or matrix
   \item{\code{character}} if \code{X} is of type \code{ExpressionSet}. In
   this case \code{y} may be the name of 
   the survival response in the phenoData of \code{X}. If survival time and indicator are stored separately in the phenoData
   one can specify a two-element character vector the first element representing the survival time variable.
          }}
  \item{survmethod}{Name of the function (as character) ending with
    \code{surv} indicating the survival method to be used.}
   \item{measure}{Peformance measure to be used:
                 \describe{
                 \item{\code{"CvPLogL"}}{Cross-validated partial log likelihood}
                 \item{\code{"PErrC"}}{Prediction Error Curves}
                 \item{\code{"UnoC"}}{Uno's C-Statistic}
                 \item{\code{"HarrellC"}}{Harrell's C-Statistic}
                 }
               }
	       \item{packagetune}{Shall inbuilt tuning mechanisms from
		 other packages implementing the algorithm specified in \code{survmethod} be used?
	       Defaults to \code{FALSE}}
   \item{add.surv}{list with additional parameters pssed to
 \code{learnSurvival}, see \code{\link{learnSurvival}}. One can specify
 concrete tuning parameter values here or a custom survival model via \code{customSurvModel}.}
   \item{add.tune}{list with additional parameters a call to
 \code{tune}, see \code{\link{tune}}. One can specify a tuning grid or a
 specific \code{ measure} which is just used during the tuning process.}
\item{add.measure}{List of additional arguments passed to
  \code{evaluate}, see \code{\link{evaluate}}.}
\item{plot}{Logical indicating whether a heatmap of the Zmatrix shall be
  produced in the end. Defaults to \code{FALSE}.}
\item{trace}{Should progress be traced ? Default is \code{TRUE}.}
\item{names}{Names of the datasets, useful when a heatmap shall be
  plotted.}
\item{seed}{Specify a value for the random seed for reproducibility.}
  \item{\dots}{Further arguments, currently not used.}
}
\details{This is a wrapper for the functions \code{tune},
  \code{learnSurvival} and \code{evaluate} which are called iteratively for the
  elements in \code{Xlist} and \code{ylist}.}
\value{An object of class \code{matrix}, the Zmatrix.}
\author{
    Christoph Bernau \email{bernau@ibe.med.uni-muenchen.de}
}
\seealso{\code{\link{learnSurvival}}, \code{\link{tune}}, \code{\link{evaluate}}}
       \examples{
\dontrun{
set.seed(2)
nsamples <- 100
X <- matrix(rnorm(nsamples*200),nrow=nsamples)
colnames(X) <- make.names(1:ncol(X))
rownames(X) <- make.names(1:nrow(X))
time <- rexp(nsamples)
cens <- sample(0:1,size=nsamples,replace=TRUE)
y <- Surv(time,cens)

Xlist<-list()
ylist<-list()
for(i in 1:8){
Xlist[[i]]<-X
ylist[[i]]<-y
}
add.tune<-list(grids=list())
add.surv<-list(standardize=FALSE)
Zmat<-computeZ(Xlist=Xlist,ylist=ylist,survmethod='coxBoostSurv',measure='HarrellC',add.surv=add.surv,add.tune=add.tune,packagetune=FALSE,plot=T,seed=222)
print(Zmat)
}
}
\keyword{multivariate, cross-study-validation}
