\name{evaluate}
\alias{evaluate}
\alias{evaluate,ModelLearned-method}
\alias{evaluate,ModelBase-method}
\alias{evaluate,LearnOut-method}
\alias{evaluate,CvPLogL-method}
\alias{evaluate,HarrellC-method}
\alias{evaluate,LinearPrediction-method}
\alias{evaluate,PErrC-method}
\alias{evaluate,coxph-method}
\alias{evaluate,SurvivalProbs-method}
\alias{evaluate,UnoC-method}


\title{Evaluation of survival methods}
\description{
  The performance of survival methods can be evaluated by different
  measures that are described more precisely
  below.\cr
  
}
\usage{
\S4method{evaluate}{LearnOut}(object,measure="CvPLogL",newdata=NULL,newy=NULL,index=NULL,imputezero=FALSE,...)
\S4method{evaluate}{ModelLearned}(object, newdata, newy, measure = "CvPLogL", add = list(), ...)
\S4method{evaluate}{ModelBase}(object, newdata, newy, measure = "CvPLogL", add = list(), lptrain = NULL, ytrain = NULL, ...)
}
\arguments{
  \item{object}{An object of class \code{LearnOut},\code{ModelLearned} or \code{ModelBase} returned by a call to method \code{learnSurvival}.}
                  
  \item{measure}{Peformance measure to be used:
                 \describe{
                 \item{\code{"CvPLogL"}}{Cross-validated partial log likelihood}
                 \item{\code{"PErrC"}}{Prediction Error Curves}
                 \item{\code{"UnoC"}}{Uno's C-Statistic}
                 \item{\code{"HarrellC"}}{Harrell's C-Statistic}
                 }
                 }
                 \item{newdata}{if the model is to be evaluated on independent new data these can be specified here}
                 \item{newy}{survival response for the independent test data mentioned in the previous \code{newdata} argument}
                 \item{index}{the index of the model that is to be
                 evaluated (if object is of class \code{LearnOut} which
                 usually conatains several models)}
	       \item{imputezero}{If TRUE, missing variables in newdata
                 will be given a value of zero.}
                 \item{add}{\code{list} of additional arguments for the internal call to \code{predict}. Usually not specified by the user.}
                 \item{lptrain}{if \code{object} is of class \code{ModelBase} this argument contains the linear predictor for the training observations which is needed for certain measures.}
                 \item{ytrain}{if \code{object} is of class \code{ModelBase} this argument contains the survival response for the training observations which is needed for certain measures.}
                \item{...}{Further arguments needed for the computation of the specified measure (s. basic measure functions in 'see also'-section).}
                            }
      
\value{An object of class \code{\link{EvaluateOutput}}.}
\references{ 
Verweij, P.J.M. and van Houweilingen, H.C. (1993) Cross-Validation in Survival Analysis, Statistics in Medicine, 12, 2305-2314


Uno, H., et al. (2009), On The C-Statistics For Evaluating Overall Adequacy Of Risk Prediction Procedures With Censored Survival Data, Harvard University Biostatistics Working Series, Paper 101


}
            

\author{Christoph Bernau \email{bernau@ibe.med.uni-muenchen.de}}

\seealso{\code{\link{EvaluateOutput}}, \code{\link{learnSurvival}}}
\examples{
\dontrun{
	data(beer.exprs)
	set.seed(123)
	X<-t(as.matrix(beer.exprs))
	data(beer.survival)
	y<-Surv(beer.survival[,2],beer.survival[,1])
	
	ls<-generateLearningsets(y=y[,1],method='CV',fold=3,niter=2)
	
	svaggr<-learnSurvival(X=X,y=y,survmethod='coxBoostSurv',LearningSets=ls)
	evaluate(svaggr,measure='CvPLogL')
	evaluate(svaggr,measure='CvPLogL',newdata=X,newy=y,index=1)
	}
}

\keyword{multivariate}

