\name{geneSelection}
\alias{geneSelection}
\alias{geneSelection,ExpressionSet,character-method}
\alias{geneSelection,ExpressionSet,Surv-method}
\alias{geneSelection,data.frame,Surv-method}
\alias{geneSelection,matrix,Surv-method}
\title{general method for variable selection with various methods}
\description{
 For different learning data sets as defined by the argument \code{LearningSets},
 this method ranks the genes from the most relevant to the less relevant using
 one of various 'filter' criteria or provides a sparse collection of variables
 (Lasso, ElasticNet, Boosting). The results are typically used for variable selection for
 the classification procedure that follows.\cr
 For S4 class information, s. \code{GeneSelection-methods}.
}
\usage{
\S4method{geneSelection}{data.frame,Surv}(X, y, LearningSets, method = c("fastCox"), criterion, trace = TRUE, ...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
 \item{X}{Gene expression data. The following formats are available:
  \itemize{
   \item{\code{matrix}} Rows correspond to observations, columns to variables.
   \item{\code{data.frame}}  Rows correspond to observations, columns to variables.
   \item{\code{ExpressionSet}} survHD will extract the expressions using exprs().
  } }
  \item{y}{Survival Response, an object of class:
  \itemize{
   \item{\code{Surv}} if \code{X} is of type data.frame or matrix
   \item{\code{character}} if \code{X} is of type \code{ExpressionSet}. In
   this case \code{y} may be the name of 
   the survival response in the phenoData of \code{X}. If survival time and indicator are stored separately in the phenoData
   one can specify a two-element character vector the first element representing the survival time variable.
          }}
  \item{LearningSets}{An object of class \code{\link{LearningSets}}. May
                      be missing, then the complete datasets is used as
                      learning set.}
  \item{method}{A character specifying the method to be used. Can be one of the following
   (consult \code{\link{filter}} for more information):
                \describe{
	     \item{\code{fastCox}}{Performs a univariate Coxmodel for each column of \code{X}} 
	      }
	      }
  \item{criterion}{can be either "pvalue" or "coefficient" and determines which of these two criteria shall be returned by \code{method}}
  \item{trace}{Should the progress be traced ? Default is \code{TRUE}.}
  \item{\dots}{Further arguments passed to the function performing variable selection, s. \code{method}.}
}
%\details{
%  ~~ If necessary, more details than the description above ~~
%}

\value{An object of class \code{\link{GeneSel}}.}
\references{
          Cox, D. R. (1972) Regression models and life tables (with discussion), Journal of the Royal Statistical Society,
Series B, 34, 187-220   
            }
\author{Christoph Bernau \email{bernau@ibe.med.uni-muenchen.de},
Martin Slawski \email{ms@cs.uni-sb.de}, 
Anne-Laure Boulesteix \email{boulesteix@ibe.med.uni-muenchen.de}
}
\seealso{\code{\link{fastCox}}, \code{\link{generateLearningsets}}, \code{\link{tune}},
         \code{\link{learnSurvival}}}
\examples{
set.seed(2)
nsamples <- 100
X <- matrix(rnorm(nsamples*200),nrow=nsamples)
colnames(X) <- make.names(1:ncol(X))
rownames(X) <- make.names(1:nrow(X))
time <- rexp(nsamples)
cens <- sample(0:1,size=nsamples,replace=TRUE)
y <- Surv(time,cens)
##bootds defines outer fold:
LearningSets <- generateLearningsets(y = y, method = "CV", fold = 5, niter = 1, strat = TRUE)

gsel<-geneSelection(X=X,y=y,LearningSets=LearningSets,method='fastCox',criterion='pvalue')
  print(gsel)
importance(gsel)[[1]][1:5,1:3]
rankings(gsel)[[1]][1:5,1:3]

}
\keyword{multivariate}
