\name{Barplot}
\alias{plot,GeneSel-method}
\alias{plot,GeneSel,missing-method}
\title{Barplot of variable importance}
\description{ The plot visualizes
             variable importance by a barplot. The height
             of the barplots correspond to variable importance.
             What variable importance exactly means depends
             on the method chosen when calling \code{\link{geneSelection}},
             s. \code{\link{GeneSel}}.}

\arguments{
  \item{x}{An object of class \code{\link{GeneSel}}}
  \item{top}{Number of top genes whose variable importance should be displayed.
             Defaults to 10.}
  \item{iter}{Iteration number (\code{learningset}) for which variable
              importance should be displayed.}
  \item{\dots}{Further graphical options passed to \code{barplot}.}
}
\note{Note the following
      \itemize{
      \item If \code{scheme = "multiclass"}, only one plot will be made.
            Otherwise, one plot will be made for each binary scenario
            (depending on whether \code{"scheme"} is \code{"one-vs-all"}
            or \code{"pairwise"}).
      \item Variable importance do not make sense for variable selection
            (ranking) methods that are essentially discrete, such as
            the Wilcoxon-Rank sum statistic or the Kruskal-Wallis statistic.
      \item For the methods \code{"lasso", "elasticnet", "boosting"}
            the number of nonzero coefficients can be very small, resulting
            in bars of height zero if \code{top} has been chosen too
	    large.
	    }
      }
\value{No return.}

\author{
Christoph Bernau \email{bernau@ibe.med.uni-muenchen.de}

Martin Slawski \email{ms@cs.uni-sb.de}

        Anne-Laure Boulesteix \email{boulesteix@ibe.med.uni-muenchen.de}}
\seealso{\code{\link{GeneSel}}, \code{\link{geneSelection}}}
\examples{
set.seed(2)
nsamples <- 100
X <- matrix(rnorm(nsamples*200),nrow=nsamples)
colnames(X) <- make.names(1:ncol(X))
rownames(X) <- make.names(1:nrow(X))
time <- rexp(nsamples)
cens <- sample(0:1,size=nsamples,replace=TRUE)
y <- Surv(time,cens)
##bootds defines outer fold:
LearningSets <- generateLearningsets(y = y, method = "CV", fold = 5, niter = 1, strat = TRUE)

gsel<-geneSelection(X=X,y=y,LearningSets=LearningSets,method='fastCox',criterion='pvalue')
plot(gsel)


}
\keyword{multivariate}
