\name{rowCoxTests}
\alias{rowCoxTests}
\title{
Fast Cox proportional hazards model fit for each row of a matrix
}
\description{
This function is analogous to the rowttests and rowFtests functions of
the genefilter package, but for a Cox proportional hazards model.
Looping over each row is done in C, so it is much faster than running
the survival:coxph function on each row.
}
\usage{
rowCoxTests(X, y, option,...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
 \item{X}{Gene expression data. The following formats are available:
  \itemize{
   \item{\code{matrix}} Rows correspond to observations, columns to variables.
   \item{\code{data.frame}}  Rows correspond to observations, columns to variables.
   \item{\code{ExpressionSet}} survHD will extract the expressions using exprs().
  } }
  \item{y}{Survival Response, an object of class:
  \itemize{
   \item{\code{Surv}} if \code{X} is of type data.frame or matrix
   \item{\code{character}} if \code{X} is of type \code{ExpressionSet}. In this case y is the name of 
   the survival response in the phenoData of \code{X}. If survival time and indicator are stored separately in the phenoData
   one can specify a two-element character vector the first element representing the survival time variable.
          }}
  
  \item{option}{"fast" loops over rows in C, "slow" calls coxph directly
  in R.  The latter method may be used if something goes wrong with the
  "fast" method.}
  \item{\dots}{currently unused}
}
\value{
  Output is a dataframe with three columns:
  
\item{coef}{coefficient of Cox regression (hazard ratio for a binary covariate)}
\item{se.coef}{Standard error of the Cox coefficient}
\item{p.value}{p-value of the Wald test for each row of X}

The dataframe has one row for each row of X, with the same rownames.
}
\author{
Christoph Bernau \email{bernau@ibe.med.uni-muenchen.de}
Levi Waldron \email{lwaldron@hsph.harvard.edu}
}

\seealso{
\code{\link{coxph}}
}
\examples{
#test
##regressor-matrix (gene expressions)
X<-matrix(rnorm(1e6),nrow=10000)
#seed
set.seed(123)
#times
time<-rnorm(n=ncol(X),mean=100)
#censoring(1->death)
status<-rbinom(n=ncol(X),size=1, prob=0.8)

##survival object
y<-Surv(time,status)

## Do 10,000 Cox regressions:
system.time(output <- rowCoxTests(X=X,y=y, option="fast"))
}
\keyword{survival}
